from PyObjCTools.TestSupport import TestCase

import Virtualization


class TestVZVirtualMachine(TestCase):
    def test_constants(self):
        self.assertEqual(Virtualization.VZVirtualMachineStateStopped, 0)
        self.assertEqual(Virtualization.VZVirtualMachineStateRunning, 1)
        self.assertEqual(Virtualization.VZVirtualMachineStatePaused, 2)
        self.assertEqual(Virtualization.VZVirtualMachineStateError, 3)
        self.assertEqual(Virtualization.VZVirtualMachineStateStarting, 4)
        self.assertEqual(Virtualization.VZVirtualMachineStatePausing, 5)
        self.assertEqual(Virtualization.VZVirtualMachineStateResuming, 6)

    def test_methods(self):
        self.assertResultIsBOOL(Virtualization.VZVirtualMachine.isSupported)
        self.assertResultIsBOOL(Virtualization.VZVirtualMachine.canStart)
        self.assertResultIsBOOL(Virtualization.VZVirtualMachine.canPause)
        self.assertResultIsBOOL(Virtualization.VZVirtualMachine.canResume)
        self.assertResultIsBOOL(Virtualization.VZVirtualMachine.canRequestStop)

        self.assertArgIsBlock(
            Virtualization.VZVirtualMachine.startWithCompletionHandler_, 0, b"v@"
        )
        self.assertArgIsBlock(
            Virtualization.VZVirtualMachine.pauseWithCompletionHandler_, 0, b"v@"
        )
        self.assertArgIsBlock(
            Virtualization.VZVirtualMachine.resumeWithCompletionHandler_, 0, b"v@"
        )

        self.assertResultIsBOOL(Virtualization.VZVirtualMachine.requestStopWithError_)
        self.assertArgIsOut(Virtualization.VZVirtualMachine.requestStopWithError_, 0)



from PyObjCTools.TestSupport import TestCase
import objc
import Virtualization  # noqa: F401


class TestVZVirtualMachineDelegate(TestCase):
    def test_protocols(self):
        objc.protocolNamed("VZVirtualMachineDelegate")



# This file is generated by objective.metadata
#
# Last update: Wed Aug  5 14:49:53 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$VZErrorDomain$"""
enums = """$VZErrorInternal@1$VZErrorInvalidDiskImage@5$VZErrorInvalidVirtualMachineConfiguration@2$VZErrorInvalidVirtualMachineState@3$VZErrorInvalidVirtualMachineStateTransition@4$VZVirtualMachineStateError@3$VZVirtualMachineStatePaused@2$VZVirtualMachineStatePausing@5$VZVirtualMachineStateResuming@6$VZVirtualMachineStateRunning@1$VZVirtualMachineStateStarting@4$VZVirtualMachineStateStopped@0$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"guestDidStopVirtualMachine:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"listener:shouldAcceptNewConnection:fromSocketDevice:",
        {
            "required": False,
            "retval": {"type": b"Z"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"virtualMachine:didStopWithError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"VZDiskImageStorageDeviceAttachment",
        b"initWithURL:readOnly:error:",
        {"arguments": {3: {"type": b"Z"}, 4: {"type_modifier": b"o"}}},
    )
    r(b"VZDiskImageStorageDeviceAttachment", b"isReadOnly", {"retval": {"type": "Z"}})
    r(b"VZFileSerialPortAttachment", b"append", {"retval": {"type": b"Z"}})
    r(
        b"VZFileSerialPortAttachment",
        b"initWithURL:append:error:",
        {"arguments": {3: {"type": b"Z"}, 4: {"type_modifier": b"o"}}},
    )
    r(b"VZMACAddress", b"isBroadcastAddress", {"retval": {"type": b"Z"}})
    r(b"VZMACAddress", b"isLocallyAdministeredAddress", {"retval": {"type": b"Z"}})
    r(b"VZMACAddress", b"isMulticastAddress", {"retval": {"type": b"Z"}})
    r(b"VZMACAddress", b"isUnicastAddress", {"retval": {"type": b"Z"}})
    r(b"VZMACAddress", b"isUniversallyAdministeredAddress", {"retval": {"type": b"Z"}})
    r(
        b"VZVirtioSocketDevice",
        b"connectToPort:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"VZVirtualMachine", b"canPause", {"retval": {"type": b"Z"}})
    r(b"VZVirtualMachine", b"canRequestStop", {"retval": {"type": b"Z"}})
    r(b"VZVirtualMachine", b"canResume", {"retval": {"type": b"Z"}})
    r(b"VZVirtualMachine", b"canStart", {"retval": {"type": b"Z"}})
    r(b"VZVirtualMachine", b"isSupported", {"retval": {"type": b"Z"}})
    r(
        b"VZVirtualMachine",
        b"pauseWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"VZVirtualMachine",
        b"requestStopWithError:",
        {"retval": {"type": b"Z"}, "arguments": {2: {"type_modifier": b"o"}}},
    )
    r(
        b"VZVirtualMachine",
        b"resumeWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"VZVirtualMachine",
        b"startWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"VZVirtualMachineConfiguration",
        b"validateWithError:",
        {"retval": {"type": b"Z"}, "arguments": {2: {"type_modifier": b"o"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase

import Virtualization


class TestVZVirtualMachineConfiguration(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(
            Virtualization.VZVirtualMachineConfiguration.validateWithError_
        )
        self.assertArgIsOut(
            Virtualization.VZVirtualMachineConfiguration.validateWithError_, 0
        )



from PyObjCTools.TestSupport import TestCase

import Virtualization


class TestVZVirtioSocketDevice(TestCase):
    def test_methods(self):
        self.assertArgIsBlock(
            Virtualization.VZVirtioSocketDevice.connectToPort_completionHandler_,
            1,
            b"v@@",
        )



from PyObjCTools.TestSupport import TestCase

import Virtualization


class TestVZDiskImageStorageDeviceAttachment(TestCase):
    def test_methods(self):
        self.assertArgIsBOOL(
            Virtualization.VZDiskImageStorageDeviceAttachment.initWithURL_readOnly_error_,
            1,
        )
        self.assertArgIsOut(
            Virtualization.VZDiskImageStorageDeviceAttachment.initWithURL_readOnly_error_,
            2,
        )
        self.assertResultIsBOOL(
            Virtualization.VZDiskImageStorageDeviceAttachment.isReadOnly
        )



from PyObjCTools.TestSupport import TestCase

import Virtualization


class TestVZError(TestCase):
    def test_constants(self):
        self.assertEqual(Virtualization.VZErrorInternal, 1)
        self.assertEqual(Virtualization.VZErrorInvalidVirtualMachineConfiguration, 2)
        self.assertEqual(Virtualization.VZErrorInvalidVirtualMachineState, 3)
        self.assertEqual(Virtualization.VZErrorInvalidVirtualMachineStateTransition, 4)
        self.assertEqual(Virtualization.VZErrorInvalidDiskImage, 5)



from PyObjCTools.TestSupport import TestCase

import Virtualization


class TestVZMACAddress(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(Virtualization.VZMACAddress.isBroadcastAddress)
        self.assertResultIsBOOL(Virtualization.VZMACAddress.isMulticastAddress)
        self.assertResultIsBOOL(Virtualization.VZMACAddress.isUnicastAddress)
        self.assertResultIsBOOL(
            Virtualization.VZMACAddress.isLocallyAdministeredAddress
        )
        self.assertResultIsBOOL(
            Virtualization.VZMACAddress.isUniversallyAdministeredAddress
        )



from PyObjCTools.TestSupport import TestCase

import Virtualization


class TestVZFileSerialPortAttachment(TestCase):
    def test_methods(self):
        self.assertArgIsBOOL(
            Virtualization.VZFileSerialPortAttachment.initWithURL_append_error_, 1
        )
        self.assertArgIsOut(
            Virtualization.VZFileSerialPortAttachment.initWithURL_append_error_, 2
        )

        self.assertResultIsBOOL(Virtualization.VZFileSerialPortAttachment.append)



"""
Python mapping for the Virtualization framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from Virtualization import _metadata

from Virtualization import _Virtualization

sys.modules["Virtualization"] = mod = objc.ObjCLazyModule(
    "Virtualization",
    "com.apple.Virtualization",
    objc.pathForFramework("/System/Library/Frameworks/Virtualization.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_Virtualization, Foundation),
)


del sys.modules["Virtualization._metadata"]



from PyObjCTools.TestSupport import TestCase
import objc
import Virtualization


class TestVZVirtioSocketListenerHelper(Virtualization.NSObject):
    def listener_shouldAcceptNewConnection_fromSocketDevice_(self, a, b, c):
        return 1


class TestVZVirtioSocketListener(TestCase):
    def test_protocols(self):
        objc.protocolNamed("VZVirtioSocketListenerDelegate")

    def test_methods(self):
        self.assertResultIsBOOL(
            TestVZVirtioSocketListenerHelper.listener_shouldAcceptNewConnection_fromSocketDevice_
        )
